@@ -3,25 +3,27 @@
  * @file        vncproxy.c
  * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
  * @copyright   Copyright (c) 2010-2015 HUBzero Foundation, LLC.
- * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+ * @license     http://opensource.org/licenses/MIT MIT
  *
  * Copyright (c) 2010-2015 HUBzero Foundation, LLC.
  *
- * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
- * software: you can redistribute it and/or modify it under the terms of
- * the GNU Lesser General Public License as published by the Free Software
- * Foundation, either version 3 of the License, or (at your option) any
- * later version.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
- * HUBzero is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  *
  * HUBzero is a registered trademark of HUBzero Foundation, LLC.
  */
@@ -276,14 +278,10 @@ main(int argc, const char * const argv[])
 			break;
 
 		switch (c) {
-			case 'r': fprintf(stdout, "vncproxy 2.2.11\n");
-					  fprintf(stdout, "Copyright (c) 2010-2014 HUBzero Foundation, LLC.\n");
-					  fprintf(stdout, "This is free software: you can redistribute it and/or modify it under the terms\n");
-					  fprintf(stdout, "of the GNU Lesser General Public License version 3 or later.\n");
-					  fprintf(stdout, "<http://gnu.org/licenses/gpl.html>\n"); 
-					  fprintf(stdout, "\n");
-				  	  fprintf(stdout, "There is NO WARRANTY, to the extent permitted by law.\n");
-					  fprintf(stdout, "\n");
+			case 'r': fprintf(stdout, "vncproxy 2.3.0\n");
+					  fprintf(stdout, "Copyright (c) 2010-2015 HUBzero Foundation, LLC.\n");
+					  fprintf(stderr, "This is free software: you can redistribute it and/or modify it under the terms\n");
+					  fprintf(stderr, "of the MIT License (http://opensource.org/licenses/MIT)\n");
 					  fprintf(stdout, "Written by Nicholas J. Kisseberth.\n");
 					  exit(0);
 					  break;
